@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::CopyrightYearFromGit;
 
 our $DATE = '2019-10-24'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,12 +13,17 @@ with (
 );
 
 has min_year => (is => 'rw');
+has regex    => (is => 'rw');
 
 sub before_build {
     require Release::Util::Git;
     my $self = shift;
 
-    my $res = Release::Util::Git::list_git_release_years();
+    my @lgry_args;
+    if (defined $self->regex) {
+        @lgry_args = ( regex => $self->regex );
+    }
+    my $res = Release::Util::Git::list_git_release_years(@lgry_args);
     $self->log_fatal(["%s - %s"], $res->[0], $res->[1]) unless $res->[0] == 200;
 
     my $cur_year = (localtime)[5]+1900;
@@ -55,7 +60,7 @@ Dist::Zilla::Plugin::CopyrightYearFromGit - Set copyright year from git
 
 =head1 VERSION
 
-This document describes version 0.004 of Dist::Zilla::Plugin::CopyrightYearFromGit (from Perl distribution Dist-Zilla-Plugin-CopyrightYearFromGit), released on 2019-10-24.
+This document describes version 0.005 of Dist::Zilla::Plugin::CopyrightYearFromGit (from Perl distribution Dist-Zilla-Plugin-CopyrightYearFromGit), released on 2019-10-24.
 
 =head1 SYNOPSIS
 
@@ -86,6 +91,10 @@ Instruct the plugin to not include years below this year. Note that the current
 year will always be used, even though C<min_year> is (incorrectly) set to a
 value larger than the current year.
 
+=head2 regex
+
+Specify a custom regular expression for matching version strings in git tags.
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla-Plugin-CopyrightYearFromGit>.
